#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vty
version:              6.2
visibility:           public
id:                   vty-6.2-CcZ776bo6BiAOEDbH1SiWY
key:                  vty-6.2-CcZ776bo6BiAOEDbH1SiWY
license:              BSD-3-Clause
maintainer:           Jonathan Daugherty (cygnus@foobox.com)
author:               AUTHORS
homepage:             https://github.com/jtdaugherty/vty
synopsis:             A simple terminal UI library
description:
    vty is terminal GUI library in the niche of ncurses. It is intended to
    be easy to use and to provide good support for common terminal types.

    See the @vty-examples@ package as well as the program
    @examples/interactive_terminal_test.hs@ included in the @vty@
    repository for examples on how to use the library.

    Import the @Graphics.Vty@ convenience module to get access to the core
    parts of the library.

    &#169; 2006-2007 Stefan O'\''Rear; BSD3 license.

    &#169; Corey O'\''Connor; BSD3 license.

    &#169; Jonathan Daugherty; BSD3 license.

category:             User Interfaces
abi:                  3136305e9cc878d0b52df040126d5f90
exposed:              True
exposed-modules:
    Graphics.Text.Width Graphics.Vty Graphics.Vty.Attributes
    Graphics.Vty.Attributes.Color Graphics.Vty.Attributes.Color240
    Graphics.Vty.Config Graphics.Vty.Debug
    Graphics.Vty.DisplayAttributes Graphics.Vty.Error
    Graphics.Vty.Image Graphics.Vty.Image.Internal Graphics.Vty.Inline
    Graphics.Vty.Input Graphics.Vty.Input.Events Graphics.Vty.Output
    Graphics.Vty.Output.Mock Graphics.Vty.Picture
    Graphics.Vty.PictureToSpans Graphics.Vty.Span
    Graphics.Vty.UnicodeWidthTable.IO
    Graphics.Vty.UnicodeWidthTable.Install
    Graphics.Vty.UnicodeWidthTable.Main
    Graphics.Vty.UnicodeWidthTable.Query
    Graphics.Vty.UnicodeWidthTable.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/vty-6.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/vty-6.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/vty-6.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vty
hs-libraries:         HSvty-6.2-CcZ776bo6BiAOEDbH1SiWY
depends:
    base-4.18.2.1 binary-0.8.9.1
    blaze-builder-0.4.4.1-FEj65wWpaUs60ShEedjm3y bytestring-0.11.5.3
    deepseq-1.4.8.1 directory-1.3.8.5 filepath-1.4.300.1
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    microlens-mtl-0.2.1.0-Ewo8HmKpWhTASatFX3KZGS mtl-2.3.1
    parsec-3.1.16.1 stm-2.5.1.0 text-2.0.2
    utf8-string-1.0.2-2At7L47Qsbs4rlGLlJEQb1
    vector-0.13.2.0-EFjd2WQg5nEG5BmM55CoiV

haddock-interfaces:   /usr/share/doc/haskell-vty/html/vty.haddock
haddock-html:         /usr/share/doc/haskell-vty/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

